@@ -69,17 +69,17 @@ class GetData(object):
                      response_download = self.client.client(url_download,{},"GET",force_raise=True,enable_stream=True)
                  except Exception as e:
                      self.LOG.exception("Un error occurd : %s"%(e))
-                     raise AdamApiError( e )
+                     raise AdamApiMessage( {"error":e} )
 
                  with open(fname,"wb") as f:
                      for chunk in response_download.iter_content(chunk_size=128):
                          f.write(chunk)
                  return AdamApiMessage({"pk":params["pk"],"status":status,"location":fname})
              else:
-                 return AdamApiError({"pk":params["pk"],"status":status})
+                 return AdamApiMessage({"pk":params["pk"],"status":status})
         if fname is None:
             self.LOG.error("Unprocessable requests with productId and geometry. Execute a request with only once of two params")
-            raise AdamApiError( "Unprocessable requests with productId and geometry. Execute a request with only once of two params")
+            raise AdamApiMessage( {"error":"Unprocessable requests with productId and geometry. Execute a request with only once of two params"})
         self._checkDirFile(fname)
         if "productId" in params:
             url = os.path.join("apis","v2","opensearch",datasetId.split(":",1)[0],"records/",params["productId"]+"/","download")
@@ -117,24 +117,24 @@ class GetData(object):
                                    for chunk in response_download.iter_content(chunk_size=128):
                                        f.write(chunk)
                            except requests.exceptions.HTTPError as er:
-                               raise AdamApiError( response_download.json())
+                               raise AdamApiMessage( {"error":response_download.json()})
                            except Exception as e:
                                self.LOG.exception("Un error occurd : %s"%(e))
-                               raise AdamApiError( e )
+                               raise AdamApiMessage( {"error":e} )
                     else:
                         return AdamApiMessage(response_order.json())
 
                 if status == "failed":
                     self.LOG.error("Failed request")
-                    raise AdamApiError(status)
+                    raise AdamApiMessage({"status":status,"error":"Failed Request"})
             else:
                 with open( fname, 'wb' ) as f:
                     f.write( response_order.content )
         except requests.exceptions.HTTPError as er:
-            raise AdamApiError(response_order.json())
+            raise AdamApiMessage({"error":response_order.json()})
         except Exception as e:
             self.LOG.exception("Un error occurd : %s"%(e))
-            raise AdamApiError( e )
+            raise AdamApiMessage( {"error":e} )
 
         return fname
 
@@ -166,6 +166,7 @@ class GetData(object):
                 raise AdamApiError("Invalid Temporal Filter: startDate > endDate")
             params["start_date"]=start_date
             params["end_date"]=end_date
+        params["type"]="adamapi"
         return params,fname
 
     def _checkStatus(self,oid,asyncron):
